# LRGASP Guidelines and Tools

Documentation and software for submitting to the
Long Read Genome Annotation Assessment Project (LRGASP).

Current documentation is published at [LRGASP Guidelines and Tools](https://lrgasp.github.io/lrgasp-submissions/docs).

Synapse challenge is at [Synapse LRGASP](https://www.synapse.org/#!Synapse:syn25007472/wiki/608702)

Github repository is at [LRGASP/lrgasp-submissions](https://github.com/LRGASP/lrgasp-submissions).

Additional description of LRGASP, challenges, and challenge evaluation can be found at our [Stage 1 Registered Report](https://www.researchsquare.com/article/rs-777702/v1)

## LRGASP Submission deadline extended: October 8, 2021, 11:59PM PT
